==> o365-3.0.24.tar.gz: o365/modules/o365_onedrive/src/Plugin/Block/RecentFilesBlock.php <==
<?php

namespace Drupal\o365_onedrive\Plugin\Block;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\o365\Block\O365UncachedBlockBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Recent Files' block.
 *
 * @Block(
 *   id = "o365_recent_files",
 *   admin_label = @Translation("Recent Files"),
 *   category = @Translation("Office 365")
 * )
 */
class RecentFilesBlock extends O365UncachedBlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface definition.
   *
   * @var \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface
   */
  protected $getFilesAndFoldersService;

  /**
   * Constructs a new RecentFilesBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface $o365_onedrive_get_files
   *   The GetFilesAndFoldersServiceInterface definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GetFilesAndFoldersServiceInterface $o365_onedrive_get_files) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->getFilesAndFoldersService = $o365_onedrive_get_files;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('o365_onedrive.get_files')
    );
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   * @throws \Microsoft\Graph\Exception\GraphException
   */
  public function build() {
    $blockData = $this->getFilesAndFoldersService->listSpecialFilesAndFolders('recent');

    if (!empty($blockData)) {
      return $blockData;
    }

    $config = $this->getConfiguration();

    if ($config['show_recent_files_block']) {
      return [
        '#theme' => 'o365_onedrive_results',
        '#results' => $config['recent_files_block_text'],
      ];
    }

    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['show_recent_files_block'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show recent files when there is no data'),
      '#default_value' => ($config['show_recent_files_block']) ?? FALSE,
    ];

    $form['recent_files_block_text'] = [
      '#type' => 'textarea',
      '#title' => t('Recent files block text'),
      '#description' => $this->t('Enter the text you would like to show'),
      '#placeholder' => $this->t('Enter the text you would like to show'),
      '#default_value' => $config['recent_files_block_text'] ?? $this->t('No recent files found.'),
      '#states' => [
        'visible' => [
          ':input[name="settings[show_recent_files_block]"]' => [
            'checked' => TRUE,
          ],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['show_recent_files_block'] = $values['show_recent_files_block'];
    $this->configuration['recent_files_block_text'] = $values['recent_files_block_text'];
  }

}

==> o365-5.0.2.tar.gz: o365/modules/o365_onedrive/src/Plugin/Block/RecentFilesBlock.php <==
<?php

namespace Drupal\o365_onedrive\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\o365\Block\O365UncachedBlockBase;
use Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Recent Files' block.
 *
 * @Block(
 *   id = "o365_recent_files",
 *   admin_label = @Translation("Recent Files"),
 *   category = @Translation("Office 365")
 * )
 */
class RecentFilesBlock extends O365UncachedBlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface definition.
   *
   * @var \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface
   */
  protected $getFilesAndFoldersService;

  /**
   * Constructs a new RecentFilesBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface $o365_onedrive_get_files
   *   The GetFilesAndFoldersServiceInterface definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GetFilesAndFoldersServiceInterface $o365_onedrive_get_files) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->getFilesAndFoldersService = $o365_onedrive_get_files;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('o365_onedrive.get_files')
    );
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   * @throws \Microsoft\Graph\Exception\GraphException
   */
  public function build() {
    $blockData = $this->getFilesAndFoldersService->listSpecialFilesAndFolders('recent');

    if (!empty($blockData)) {
      return $blockData;
    }

    $config = $this->getConfiguration();

    if ($config['show_recent_files_block']) {
      return [
        '#theme' => 'o365_onedrive_results',
        '#results' => $config['recent_files_block_text'],
      ];
    }

    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['show_recent_files_block'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show recent files when there is no data'),
      '#default_value' => ($config['show_recent_files_block']) ?? FALSE,
    ];

    $form['recent_files_block_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Recent files block text'),
      '#description' => $this->t('Enter the text you would like to show'),
      '#placeholder' => $this->t('Enter the text you would like to show'),
      '#default_value' => $config['recent_files_block_text'] ?? $this->t('No recent files found.'),
      '#states' => [
        'visible' => [
          ':input[name="settings[show_recent_files_block]"]' => [
            'checked' => TRUE,
          ],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['show_recent_files_block'] = $values['show_recent_files_block'];
    $this->configuration['recent_files_block_text'] = $values['recent_files_block_text'];
  }

}
